# shippy
![version](https://img.shields.io/github/v/release/ericswpark/shippy)
![commits-since](https://img.shields.io/github/commits-since/ericswpark/shippy/latest)

Client-side tool to interface with shipper

# Usage

Get shippy from PyPI:

```shell
pip3 install shipper-shippy
```

Go to the directory with build files, and run:

```shell
shippy
```